__title__ = "kyo"
__author__ = "Standby"
__license__ = "MIT"
__copyright__ = "Copyright 2020-2022 Standby"
__version__ = "1.1.0"

from .acm import ACM
from .client import Client
from .sub_client import SubClient
from .socket import Callbacks, SocketHandler

from .lib.util import device, exceptions, headers, helpers, objects

from requests import get
from json import loads

__newest__ = loads(get("https://pypi.python.org/pypi/kyo/json").text)["info"]["version"]

if __version__ != __newest__:
    print(exceptions.LibraryUpdateAvailable(f"New version of {__title__} available: {__newest__} (Using {__version__})"))



from setuptools import setup, find_packages

with open("README.md", "r") as stream:
    long_description = stream.read()

setup(
    name = "kyo",
    version = "1.1.0",
    url = "https://github.com/Sstandby/kyo",
    download_url = "https://github.com/Sstandby/kyo/tarball/master",
    license = "MIT",
    author = "Sstandby",
    author_email = "standby@sstandby.com",
    description = "Library for the creation of bots from the AminoApps platform.",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    keywords = [
        "aminoapps",
        "kyo",
        "amino",
        "aminokyo",
        "aminobots",
        "amino-bot",
        "narvii",
        "api",
        "python",
        "python3",
        "python3.x",
        "sstandby",
        "standby",
        "official"
    ],
    install_requires = [
        "setuptools",
        "requests",
        "six",
        "websockets",
        "json_minify",
        "websocket-client==1.3.1",
        "aiohttp"
    ],
    setup_requires = [
        "wheel"
    ],
    packages = find_packages()
)
